#############
API reference
#############

These are the modules in maturity order:

.. currentmodule:: pandalone
.. autosummary::

    xleash
    mappings
    pandata
    components

Module: :mod:`pandalone.xleash`
===============================
.. automodule:: pandalone.xleash
    :members:

Submodule: :mod:`pandalone.xleash._parse`
-------------------------------------------
.. automodule:: pandalone.xleash._parse
    :members:

Submodule: :mod:`pandalone.xleash.io`
-------------------------------------------
.. automodule:: pandalone.xleash.io

Submodule: :mod:`pandalone.xleash.io._sheets`
-----------------------------------------------
.. automodule:: pandalone.xleash.io._sheets
    :members:

Submodule: :mod:`pandalone.xleash.io._xlrd`
--------------------------------------------
.. automodule:: pandalone.xleash.io._xlrd
    :members:

Submodule: :mod:`pandalone.xleash._capture`
-------------------------------------------
.. automodule:: pandalone.xleash._capture
    :members:

Submodule: :mod:`pandalone.xleash._filter`
-------------------------------------------
.. automodule:: pandalone.xleash._filter
    :members:

Submodule: :mod:`pandalone.xleash._lasso`
-----------------------------------------
.. automodule:: pandalone.xleash._lasso
    :members:

Module: :mod:`pandalone.mappings`
=================================

.. automodule:: pandalone.mappings
    :members:

Module: :mod:`pandalone.components`
===================================

.. automodule:: pandalone.components
    :members:

Module: :mod:`pandalone.pandata`
================================
.. automodule:: pandalone.pandata
    :members:

